@@ -1,6 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+)
 
 import numpy as np
 import astropy.units as u
@@ -16,23 +20,29 @@ from .plot import find_ML
 
 try:
     import yaml
+
     HAS_PYYAML = True
 except ImportError:
     HAS_PYYAML = False
 
 __all__ = [
-    "save_diagnostic_plots", "save_results_table", "save_run", "read_run"
+    "save_diagnostic_plots",
+    "save_results_table",
+    "save_run",
+    "read_run",
 ]
 
 
-def save_diagnostic_plots(outname,
-                          sampler,
-                          modelidxs=None,
-                          pdf=False,
-                          sed=True,
-                          blob_labels=None,
-                          last_step=False,
-                          dpi=100):
+def save_diagnostic_plots(
+    outname,
+    sampler,
+    modelidxs=None,
+    pdf=False,
+    sed=True,
+    blob_labels=None,
+    last_step=False,
+    dpi=100,
+):
     """
     Generate diagnostic plots.
 
@@ -69,46 +79,52 @@ def save_diagnostic_plots(outname,
 
     from .plot import plot_chain, plot_blob, plot_corner
     from matplotlib import pyplot as plt
+
     # This function should never be interactive
-    old_interactive = plt.rcParams['interactive']
-    plt.rcParams['interactive'] = False
+    old_interactive = plt.rcParams["interactive"]
+    plt.rcParams["interactive"] = False
 
     if pdf:
-        plt.rc('pdf', fonttype=42)
-        log.info('Saving diagnostic plots in file '
-                 '{0}_plots.pdf'.format(outname))
+        plt.rc("pdf", fonttype=42)
+        log.info(
+            "Saving diagnostic plots in file " "{0}_plots.pdf".format(outname)
+        )
         from matplotlib.backends.backend_pdf import PdfPages
-        outpdf = PdfPages('{0}_plots.pdf'.format(outname))
+
+        outpdf = PdfPages("{0}_plots.pdf".format(outname))
 
     # Chains
 
     for par, label in six.moves.zip(
-            six.moves.range(sampler.chain.shape[-1]), sampler.labels):
+        six.moves.range(sampler.chain.shape[-1]), sampler.labels
+    ):
         try:
-            log.info('Plotting chain of parameter {0}...'.format(label))
+            log.info("Plotting chain of parameter {0}...".format(label))
             f = plot_chain(sampler, par, last_step=last_step)
             if pdf:
-                f.savefig(outpdf, format='pdf', dpi=dpi)
+                f.savefig(outpdf, format="pdf", dpi=dpi)
             else:
-                if 'log(' in label or 'log10(' in label:
-                    label = label.split('(')[-1].split(')')[0]
-                f.savefig('{0}_chain_{1}.png'.format(outname, label), dpi=dpi)
+                if "log(" in label or "log10(" in label:
+                    label = label.split("(")[-1].split(")")[0]
+                f.savefig("{0}_chain_{1}.png".format(outname, label), dpi=dpi)
             f.clf()
             plt.close(f)
         except Exception as e:
-            log.warning('plot_chain failed for paramter'
-                        ' {0} ({1}): {2}'.format(label, par, e))
+            log.warning(
+                "plot_chain failed for paramter"
+                " {0} ({1}): {2}".format(label, par, e)
+            )
 
     # Corner plot
 
-    log.info('Plotting corner plot...')
+    log.info("Plotting corner plot...")
 
     f = plot_corner(sampler)
     if f is not None:
         if pdf:
-            f.savefig(outpdf, format='pdf', dpi=dpi)
+            f.savefig(outpdf, format="pdf", dpi=dpi)
         else:
-            f.savefig('{0}_corner.png'.format(outname), dpi=dpi)
+            f.savefig("{0}_corner.png".format(outname), dpi=dpi)
         f.clf()
         plt.close(f)
 
@@ -122,50 +138,56 @@ def save_diagnostic_plots(outname,
         sed = [sed for idx in modelidxs]
 
     if blob_labels is None:
-        blob_labels = ['Model output {0}'.format(idx) for idx in modelidxs]
+        blob_labels = ["Model output {0}".format(idx) for idx in modelidxs]
     elif len(modelidxs) == 1 and isinstance(blob_labels, str):
         blob_labels = [blob_labels]
     elif len(blob_labels) < len(modelidxs):
         # Add labels
         n = len(blob_labels)
-        blob_labels += ['Model output {0}'.format(idx)
-                        for idx in modelidxs[n:]]
+        blob_labels += [
+            "Model output {0}".format(idx) for idx in modelidxs[n:]
+        ]
 
     for modelidx, plot_sed, label in six.moves.zip(
-            modelidxs, sed, blob_labels):
+        modelidxs, sed, blob_labels
+    ):
 
         try:
-            log.info('Plotting {0}...'.format(label))
+            log.info("Plotting {0}...".format(label))
             f = plot_blob(
                 sampler,
                 blobidx=modelidx,
                 label=label,
                 sed=plot_sed,
                 n_samples=100,
-                last_step=last_step)
+                last_step=last_step,
+            )
             if pdf:
-                f.savefig(outpdf, format='pdf', dpi=dpi)
+                f.savefig(outpdf, format="pdf", dpi=dpi)
             else:
-                f.savefig('{0}_model{1}.png'.format(outname, modelidx),
-                          dpi=dpi)
+                f.savefig(
+                    "{0}_model{1}.png".format(outname, modelidx), dpi=dpi
+                )
             f.clf()
             plt.close(f)
         except Exception as e:
-            log.warning('plot_blob failed for {0}: {1}'.format(label, e))
+            log.warning("plot_blob failed for {0}: {1}".format(label, e))
 
     if pdf:
         outpdf.close()
 
     # set interactive back to original
-    plt.rcParams['interactive'] = old_interactive
+    plt.rcParams["interactive"] = old_interactive
 
 
-def save_results_table(outname,
-                       sampler,
-                       format='ascii.ecsv',
-                       convert_log=True,
-                       last_step=False,
-                       include_blobs=True):
+def save_results_table(
+    outname,
+    sampler,
+    format="ascii.ecsv",
+    convert_log=True,
+    last_step=False,
+    include_blobs=True,
+):
     """
     Save an ASCII table with the results stored in the
     `~emcee.EnsembleSampler`.
@@ -211,21 +233,28 @@ def save_results_table(outname,
         Table with the results.
     """
 
-    if not HAS_PYYAML and format == 'ascii.ecsv':
-        format = 'ascii.ipac'
-        log.warning('PyYAML package is required for ECSV format,'
-                    ' falling back to {0}...'.format(format))
-    elif format not in ['ascii.ecsv', 'ascii.ipac']:
-        log.warning('The chosen table format does not have an astropy'
-                    ' writer that suppports metadata writing, no run info'
-                    ' will be saved to the file!')
+    if not HAS_PYYAML and format == "ascii.ecsv":
+        format = "ascii.ipac"
+        log.warning(
+            "PyYAML package is required for ECSV format,"
+            " falling back to {0}...".format(format)
+        )
+    elif format not in ["ascii.ecsv", "ascii.ipac"]:
+        log.warning(
+            "The chosen table format does not have an astropy"
+            " writer that suppports metadata writing, no run info"
+            " will be saved to the file!"
+        )
 
-    file_extension = 'dat'
-    if format == 'ascii.ecsv':
-        file_extension = 'ecsv'
+    file_extension = "dat"
+    if format == "ascii.ecsv":
+        file_extension = "ecsv"
 
-    log.info('Saving results table in {0}_results.{1}'.format(outname,
-                                                              file_extension))
+    log.info(
+        "Saving results table in {0}_results.{1}".format(
+            outname, file_extension
+        )
+    )
 
     labels = sampler.labels
 
@@ -237,34 +266,38 @@ def save_results_table(outname,
     quant = [16, 50, 84]
     # Do we need more info on the distributions?
     t = Table(
-        names=['label', 'median', 'unc_lo', 'unc_hi'],
-        dtype=['S72', 'f8', 'f8', 'f8'])
-    t['label'].description = 'Name of the parameter'
-    t['median'].description = 'Median of the posterior distribution function'
-    t['unc_lo'].description = (
-        'Difference between the median and the'
-        ' {0}th percentile of the pdf, ~1sigma lower uncertainty'.format(quant[
-            0]))
-    t['unc_hi'].description = (
-        'Difference between the {0}th percentile'
-        ' and the median of the pdf, ~1sigma upper uncertainty'
-        .format(quant[2])
+        names=["label", "median", "unc_lo", "unc_hi"],
+        dtype=["S72", "f8", "f8", "f8"],
+    )
+    t["label"].description = "Name of the parameter"
+    t["median"].description = "Median of the posterior distribution function"
+    t["unc_lo"].description = (
+        "Difference between the median and the"
+        " {0}th percentile of the pdf, ~1sigma lower uncertainty".format(
+            quant[0]
+        )
+    )
+    t["unc_hi"].description = (
+        "Difference between the {0}th percentile"
+        " and the median of the pdf, ~1sigma upper uncertainty".format(
+            quant[2]
+        )
     )
 
     metadata = {}
     # Start with info from the distributions used for storing the results
-    metadata['n_samples'] = dists.shape[0]
+    metadata["n_samples"] = dists.shape[0]
     # save ML parameter vector and best/median loglikelihood
     ML, MLp, MLerr, _ = find_ML(sampler, None)
-    metadata['ML_pars'] = [float(p) for p in MLp]
-    metadata['MaxLogLikelihood'] = float(ML)
+    metadata["ML_pars"] = [float(p) for p in MLp]
+    metadata["MaxLogLikelihood"] = float(ML)
 
     # compute and save BIC
     BIC = len(MLp) * np.log(len(sampler.data)) - 2 * ML
-    metadata['BIC'] = BIC
+    metadata["BIC"] = BIC
 
     # And add all info stored in the sampler.run_info dict
-    if hasattr(sampler, 'run_info'):
+    if hasattr(sampler, "run_info"):
         metadata.update(sampler.run_info)
 
     for p, label in enumerate(labels):
@@ -276,16 +309,17 @@ def save_results_table(outname,
 
         t.add_row((label, med, lo, hi))
 
-        if convert_log and ('log10(' in label or 'log(' in label):
-            nlabel = label.split('(')[-1].split(')')[0]
-            ltype = label.split('(')[0]
-            if ltype == 'log10':
-                new_dist = 10**dist
-            elif ltype == 'log':
+        if convert_log and ("log10(" in label or "log(" in label):
+            nlabel = label.split("(")[-1].split(")")[0]
+            ltype = label.split("(")[0]
+            if ltype == "log10":
+                new_dist = 10 ** dist
+            elif ltype == "log":
                 new_dist = np.exp(dist)
 
             quantiles = dict(
-                six.moves.zip(quant, np.percentile(new_dist, quant)))
+                six.moves.zip(quant, np.percentile(new_dist, quant))
+            )
             med = quantiles[50]
             lo, hi = med - quantiles[16], quantiles[84] - med
 
@@ -315,24 +349,25 @@ def save_results_table(outname,
                             blobl.append(walkerblob[idx])
                 if unit:
                     dist = np.array([b.value for b in blobl])
-                    metadata['blob{0}_unit'.format(idx)] = unit.to_string()
+                    metadata["blob{0}_unit".format(idx)] = unit.to_string()
                 else:
                     dist = np.array(blobl)
 
                 quantiles = dict(
-                    six.moves.zip(quant, np.percentile(dist, quant)))
+                    six.moves.zip(quant, np.percentile(dist, quant))
+                )
                 med = quantiles[50]
                 lo, hi = med - quantiles[16], quantiles[84] - med
 
-                t.add_row(('blob{0}'.format(idx), med, lo, hi))
+                t.add_row(("blob{0}".format(idx), med, lo, hi))
 
-    if format == 'ascii.ipac':
+    if format == "ascii.ipac":
         # Only keywords are written to IPAC tables
-        t.meta['keywords'] = {}
+        t.meta["keywords"] = {}
         for di in metadata.items():
-            t.meta['keywords'][di[0]] = {'value': di[1]}
+            t.meta["keywords"][di[0]] = {"value": di[1]}
     else:
-        if format == 'ascii.ecsv':
+        if format == "ascii.ecsv":
             # there can be no numpy arrays in the metadata (YAML doesn't like
             # them)
             for di in list(metadata.items()):
@@ -346,7 +381,7 @@ def save_results_table(outname,
         # Save it directly in meta for readability in ECSV
         t.meta.update(metadata)
 
-    t.write('{0}_results.{1}'.format(outname, file_extension), format=format)
+    t.write("{0}_results.{1}".format(outname, file_extension), format=format)
 
     return t
 
@@ -376,20 +411,21 @@ def save_run(filename, sampler, compression=True, clobber=False):
         Whether to overwrite the output filename if it exists.
     """
 
-    if filename.split('.')[-1] not in ['h5', 'hdf5']:
-        filename += '_chain.h5'
+    if filename.split(".")[-1] not in ["h5", "hdf5"]:
+        filename += "_chain.h5"
 
     if os.path.exists(filename) and not clobber:
         log.warning(
-            'Not writing file because file exists and clobber is False')
+            "Not writing file because file exists and clobber is False"
+        )
         return
 
-    f = h5py.File(filename, 'w')
-    group = f.create_group('sampler')
+    f = h5py.File(filename, "w")
+    group = f.create_group("sampler")
+    group.create_dataset("chain", data=sampler.chain, compression=compression)
     group.create_dataset(
-        'chain', data=sampler.chain, compression=compression)
-    group.create_dataset(
-        'lnprobability', data=sampler.lnprobability, compression=compression)
+        "lnprobability", data=sampler.lnprobability, compression=compression
+    )
 
     # blobs
     blob = sampler.blobs[-1][0]
@@ -398,7 +434,7 @@ def save_run(filename, sampler, compression=True, clobber=False):
             # scalar or array quantity
             units = [item.unit.to_string()]
         elif isinstance(item, float):
-            units = ['']
+            units = [""]
         elif isinstance(item, tuple) or isinstance(item, list):
             arearrs = np.all([isinstance(x, np.ndarray) for x in item])
             if arearrs:
@@ -407,11 +443,11 @@ def save_run(filename, sampler, compression=True, clobber=False):
                     if isinstance(x, u.Quantity):
                         units.append(x.unit.to_string())
                     else:
-                        units.append('')
+                        units.append("")
         else:
             log.warning(
-                'blob number {0} has unknown format and cannot be saved '
-                'in HDF5 file'
+                "blob number {0} has unknown format and cannot be saved "
+                "in HDF5 file"
             )
             continue
 
@@ -424,21 +460,23 @@ def save_run(filename, sampler, compression=True, clobber=False):
         blob = u.Quantity(blob).value
 
         blobdataset = group.create_dataset(
-            'blob{0}'.format(idx), data=blob, compression=compression)
+            "blob{0}".format(idx), data=blob, compression=compression
+        )
         if len(units) > 1:
             for j, unit in enumerate(units):
-                blobdataset.attrs['unit{0}'.format(j)] = unit
+                blobdataset.attrs["unit{0}".format(j)] = unit
         else:
-            blobdataset.attrs['unit'] = units[0]
+            blobdataset.attrs["unit"] = units[0]
 
-    if hasattr(sampler, 'data'):
+    if hasattr(sampler, "data"):
         data = group.create_dataset(
-            'data',
+            "data",
             data=Table(sampler.data).as_array(),
-            compression=compression)
+            compression=compression,
+        )
 
         for col in sampler.data.colnames:
-            f['sampler/data'].attrs[col + 'unit'] = str(sampler.data[col].unit)
+            f["sampler/data"].attrs[col + "unit"] = str(sampler.data[col].unit)
 
         for key in sampler.data.meta:
             val = sampler.data.meta[key]
@@ -451,11 +489,12 @@ def save_run(filename, sampler, compression=True, clobber=False):
                     warnings.warn(
                         "Attribute `{0}` of type {1} of the data table"
                         " of the sampler cannot be written to HDF5 files"
-                        "- skipping".format(key, type(val)), AstropyUserWarning
+                        "- skipping".format(key, type(val)),
+                        AstropyUserWarning,
                     )
 
     # add all run info to group attributes
-    if hasattr(sampler, 'run_info'):
+    if hasattr(sampler, "run_info"):
         for key in sampler.run_info.keys():
             val = sampler.run_info[key]
             try:
@@ -464,11 +503,11 @@ def save_run(filename, sampler, compression=True, clobber=False):
                 group.attrs[key] = str(val)
 
     # add other sampler info to the attrs
-    group.attrs['acceptance_fraction'] = np.mean(sampler.acceptance_fraction)
+    group.attrs["acceptance_fraction"] = np.mean(sampler.acceptance_fraction)
 
     # add labels as individual attrs (there might be a better way)
     for i, label in enumerate(sampler.labels):
-        group.attrs['label{0}'.format(i)] = label
+        group.attrs["label{0}".format(i)] = label
 
     f.close()
 
@@ -521,10 +560,10 @@ def read_run(filename, modelfn=None):
     result.modelfn = modelfn
     result.run_info = {}
 
-    f = h5py.File(filename, 'r')
+    f = h5py.File(filename, "r")
     # chain and lnprobability
-    result.chain = np.array(f['sampler/chain'])
-    result.lnprobability = np.array(f['sampler/lnprobability'])
+    result.chain = np.array(f["sampler/chain"])
+    result.lnprobability = np.array(f["sampler/lnprobability"])
 
     # blobs
     result.blobs = []
@@ -534,18 +573,20 @@ def read_run(filename, modelfn=None):
     for i in range(100):
         # first read each of the blobs and convert to Quantities
         try:
-            ds = f['sampler/blob{0}'.format(i)]
+            ds = f["sampler/blob{0}".format(i)]
             rank = np.ndim(ds[0])
             blobrank.append(rank)
             if rank <= 1:
-                blobs.append(u.Quantity(ds.value, unit=ds.attrs['unit']))
+                blobs.append(u.Quantity(ds.value, unit=ds.attrs["unit"]))
             else:
                 blob = []
                 for j in range(np.ndim(ds[0])):
                     blob.append(
                         u.Quantity(
                             ds.value[:, j, :],
-                            unit=ds.attrs['unit{0}'.format(j)]))
+                            unit=ds.attrs["unit{0}".format(j)],
+                        )
+                    )
                 blobs.append(blob)
         except KeyError:
             break
@@ -568,19 +609,19 @@ def read_run(filename, modelfn=None):
         result.blobs.append(steplist)
 
     # run info
-    result.run_info = dict(f['sampler'].attrs)
-    result.acceptance_fraction = f['sampler'].attrs['acceptance_fraction']
+    result.run_info = dict(f["sampler"].attrs)
+    result.acceptance_fraction = f["sampler"].attrs["acceptance_fraction"]
     # labels
     result.labels = []
     for i in range(result.chain.shape[2]):
-        result.labels.append(f['sampler'].attrs['label{0}'.format(i)])
+        result.labels.append(f["sampler"].attrs["label{0}".format(i)])
 
     # data
-    data = Table(np.array(f['sampler/data']))
-    data.meta.update(f['sampler/data'].attrs)
+    data = Table(np.array(f["sampler/data"]))
+    data.meta.update(f["sampler/data"].attrs)
     for col in data.colnames:
-        if f['sampler/data'].attrs[col + 'unit'] != 'None':
-            data[col].unit = f['sampler/data'].attrs[col + 'unit']
+        if f["sampler/data"].attrs[col + "unit"] != "None":
+            data[col].unit = f["sampler/data"].attrs[col + "unit"]
     result.data = QTable(data)
 
     return result
