@@ -1,7 +1,11 @@
 # -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+)
 import numpy as np
 from astropy import log
 import astropy.units as u
@@ -10,17 +14,20 @@ import warnings
 from .utils import validate_data_table, sed_conversion
 
 __all__ = [
-    "normal_prior", "uniform_prior", "log_uniform_prior", "get_sampler",
-    "run_sampler"
+    "normal_prior",
+    "uniform_prior",
+    "log_uniform_prior",
+    "get_sampler",
+    "run_sampler",
 ]
 
 # Define phsyical types used in plot and utils.validate_data_table
-u.def_physical_type(u.erg / u.cm**2 / u.s, 'flux')
-u.def_physical_type(u.Unit('1/(s cm2 erg)'), 'differential flux')
-u.def_physical_type(u.Unit('1/(s erg)'), 'differential power')
-u.def_physical_type(u.Unit('1/TeV'), 'differential energy')
-u.def_physical_type(u.Unit('1/cm3'), 'number density')
-u.def_physical_type(u.Unit('1/(eV cm3)'), 'differential number density')
+u.def_physical_type(u.erg / u.cm ** 2 / u.s, "flux")
+u.def_physical_type(u.Unit("1/(s cm2 erg)"), "differential flux")
+u.def_physical_type(u.Unit("1/(s erg)"), "differential power")
+u.def_physical_type(u.Unit("1/TeV"), "differential energy")
+u.def_physical_type(u.Unit("1/cm3"), "number density")
+u.def_physical_type(u.Unit("1/(eV cm3)"), "differential number density")
 
 # Prior functions
 
@@ -37,7 +44,7 @@ def uniform_prior(value, umin, umax):
 def normal_prior(value, mean, sigma):
     """Normal prior distribution.
     """
-    return -0.5 * (2 * np.pi * sigma) - (value - mean)**2 / (2. * sigma)
+    return -0.5 * (2 * np.pi * sigma) - (value - mean) ** 2 / (2.0 * sigma)
 
 
 def log_uniform_prior(value, umin=0, umax=None):
@@ -61,31 +68,38 @@ def log_uniform_prior(value, umin=0, umax=None):
 def lnprobmodel(model, data):
 
     # Check if conversion is required
-    model_is_sed = model.unit.physical_type in ['power', 'flux']
-    data_is_sed = data['flux'].unit.physical_type in ['power', 'flux']
+    model_is_sed = model.unit.physical_type in ["power", "flux"]
+    data_is_sed = data["flux"].unit.physical_type in ["power", "flux"]
 
     if model_is_sed != data_is_sed:
-        unit, sed_factor = sed_conversion(data['energy'], model.unit,
-                                          data_is_sed)
-        model = (model * sed_factor).to(data['flux'].unit)
+        unit, sed_factor = sed_conversion(
+            data["energy"], model.unit, data_is_sed
+        )
+        model = (model * sed_factor).to(data["flux"].unit)
 
-    ul = data['ul']
+    ul = data["ul"]
     notul = ~ul
 
-    difference = model[notul] - data['flux'][notul]
+    difference = model[notul] - data["flux"][notul]
 
     # use different errors for model above or below data
     sign = difference > 0
     loerr, hierr = 1 * ~sign, 1 * sign
-    logprob = -difference**2 / (2. * (loerr * data['flux_error_lo'][notul] +
-                                      hierr * data['flux_error_hi'][notul])**2)
+    logprob = -difference ** 2 / (
+        2.0
+        * (
+            loerr * data["flux_error_lo"][notul]
+            + hierr * data["flux_error_hi"][notul]
+        )
+        ** 2
+    )
 
     totallogprob = np.sum(logprob)
 
     if np.sum(ul) > 0:
         # deal with upper limits at CL set by data['cl']
-        violated_uls = np.sum(model[ul] > data['flux'][ul])
-        totallogprob += violated_uls * np.log(1. - data['cl'][violated_uls])
+        violated_uls = np.sum(model[ul] > data["flux"][ul])
+        totallogprob += violated_uls * np.log(1.0 - data["cl"][violated_uls])
 
     return totallogprob
 
@@ -97,20 +111,21 @@ def lnprob(pars, data, modelfunc, priorfunc):
     else:
         lnprob_priors = priorfunc(pars)
 
-# If prior is -np.inf, avoid calling the function as invalid calls may be made,
-# and the result will be discarded anyway
+    # If prior is -np.inf, avoid calling the function as invalid calls may be made,
+    # and the result will be discarded anyway
     if not np.isinf(lnprob_priors):
         modelout = modelfunc(pars, data)
 
         # Save blobs or save model if no blobs given
         # If model is not in blobs, save model+blobs
-        if ((type(modelout) == tuple or type(modelout) == list) and
-                (type(modelout) != np.ndarray)):
+        if (type(modelout) == tuple or type(modelout) == list) and (
+            type(modelout) != np.ndarray
+        ):
             model = modelout[0]
 
             MODEL_IN_BLOB = False
             for blob in modelout[1:]:
-                if np.all(blob == model):
+                if np.array_equal(blob, model):
                     MODEL_IN_BLOB = True
 
             if MODEL_IN_BLOB:
@@ -136,24 +151,40 @@ def lnprob(pars, data, modelfunc, priorfunc):
 
 def _run_mcmc(sampler, pos, nrun):
     for i, out in enumerate(sampler.sample(pos, iterations=nrun)):
-        progress = (100. * float(i) / float(nrun))
-        if progress % 5 < (5. / float(nrun)):
-            print("\nProgress of the run: {0:.0f} percent"
-                  " ({1} of {2} steps)".format(int(progress), i, nrun))
+        progress = 100.0 * float(i) / float(nrun)
+        if progress % 5 < (5.0 / float(nrun)):
+            print(
+                "\nProgress of the run: {0:.0f} percent"
+                " ({1} of {2} steps)".format(int(progress), i, nrun)
+            )
             npars = out[0].shape[-1]
             paravg, parstd = [], []
             for npar in range(npars):
                 paravg.append(np.median(out[0][:, npar]))
                 parstd.append(np.std(out[0][:, npar]))
-            print("                           " + (" ".join([
-                "{%i:-^15}" % i for i in range(npars)
-            ])).format(*sampler.labels))
-            print("  Last ensemble median : " + (" ".join(
-                ["{%i:^15.3g}" % i for i in range(npars)])).format(*paravg))
-            print("  Last ensemble std    : " + (" ".join(
-                ["{%i:^15.3g}" % i for i in range(npars)])).format(*parstd))
-            print("  Last ensemble lnprob :  avg: {0:.3f}, max: {1:.3f}"
-                  .format(np.average(out[1]), np.max(out[1])))
+            print(
+                "                           "
+                + (" ".join(["{%i:-^15}" % i for i in range(npars)])).format(
+                    *sampler.labels
+                )
+            )
+            print(
+                "  Last ensemble median : "
+                + (" ".join(["{%i:^15.3g}" % i for i in range(npars)])).format(
+                    *paravg
+                )
+            )
+            print(
+                "  Last ensemble std    : "
+                + (" ".join(["{%i:^15.3g}" % i for i in range(npars)])).format(
+                    *parstd
+                )
+            )
+            print(
+                "  Last ensemble lnprob :  avg: {0:.3f}, max: {1:.3f}".format(
+                    np.average(out[1]), np.max(out[1])
+                )
+            )
     return sampler, out[0]
 
 
@@ -171,60 +202,67 @@ def _prefit(p0, data, model, prior):
         return -lnprob(*args)[0]
 
     log.info(
-        'Finding Maximum Likelihood parameters through Nelder-Mead fitting...')
-    log.info('   Initial parameters: {0}'.format(p0))
-    log.info('   Initial lnprob(p0): {0:.3f}'.format(-nll(p0, data, model,
-                                                          prior)))
+        "Finding Maximum Likelihood parameters through Nelder-Mead fitting..."
+    )
+    log.info("   Initial parameters: {0}".format(p0))
+    log.info(
+        "   Initial lnprob(p0): {0:.3f}".format(-nll(p0, data, model, prior))
+    )
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
         result = minimize(
             nll,
             p0,
             args=(data, model, flat_prior),
-            method='Nelder-Mead',
-            options={'maxfev': 500,
-                     'xtol': 1e-1,
-                     'ftol': 1e-3})
-        ll_prior = lnprob(result['x'], data, model, prior)[0]
+            method="Nelder-Mead",
+            options={"maxfev": 500, "xtol": 1e-1, "ftol": 1e-3},
+        )
+        ll_prior = lnprob(result["x"], data, model, prior)[0]
 
-    if (result['success'] or result['status'] == 1) and not np.isinf(ll_prior):
+    if (result["success"] or result["status"] == 1) and not np.isinf(ll_prior):
         # also keep result if we have reached maxiter, it is likely
         # better than p0
-        if result['status'] == 1:
-            log.info('   Maximum number of function evaluations reached!')
-        if result['status'] == 1:
-            log.info('      New parameters : {0}'.format(result['x']))
+        if result["status"] == 1:
+            log.info("   Maximum number of function evaluations reached!")
+        if result["status"] == 1:
+            log.info("      New parameters : {0}".format(result["x"]))
         else:
-            log.info('   New ML parameters : {0}'.format(result['x']))
+            log.info("   New ML parameters : {0}".format(result["x"]))
             P0_IS_ML = True
-        if -result['fun'] == ll_prior:
-            log.info('   Maximum lnprob(p0): {0:.3f}'.format(-result['fun']))
+        if -result["fun"] == ll_prior:
+            log.info("   Maximum lnprob(p0): {0:.3f}".format(-result["fun"]))
         else:
-            log.info('flat prior lnprob(p0): {0:.3f}'.format(-result['fun']))
-            log.info('full prior lnprob(p0): {0:.3f}'.format(ll_prior))
-        p0 = result['x']
+            log.info("flat prior lnprob(p0): {0:.3f}".format(-result["fun"]))
+            log.info("full prior lnprob(p0): {0:.3f}".format(ll_prior))
+        p0 = result["x"]
     elif np.isinf(ll_prior):
-        log.warning('Maximum Likelihood procedure converged on a parameter'
-                    ' vector forbidden by prior,'
-                    ' using original parameters for MCMC')
+        log.warning(
+            "Maximum Likelihood procedure converged on a parameter"
+            " vector forbidden by prior,"
+            " using original parameters for MCMC"
+        )
     else:
-        log.warning('Maximum Likelihood procedure failed to converge,'
-                    ' using original parameters for MCMC')
+        log.warning(
+            "Maximum Likelihood procedure failed to converge,"
+            " using original parameters for MCMC"
+        )
     return p0, P0_IS_ML
 
 
-def get_sampler(data_table=None,
-                p0=None,
-                model=None,
-                prior=None,
-                nwalkers=500,
-                nburn=100,
-                guess=True,
-                interactive=False,
-                prefit=False,
-                labels=None,
-                threads=4,
-                data_sed=None):
+def get_sampler(
+    data_table=None,
+    p0=None,
+    model=None,
+    prior=None,
+    nwalkers=500,
+    nburn=100,
+    guess=True,
+    interactive=False,
+    prefit=False,
+    labels=None,
+    threads=4,
+    data_sed=None,
+):
     """Generate a new MCMC sampler.
 
     Parameters
@@ -329,24 +367,25 @@ def get_sampler(data_table=None,
     import emcee
 
     if data_table is None:
-        raise TypeError('Data table is missing!')
+        raise TypeError("Data table is missing!")
     else:
         data = validate_data_table(data_table, sed=data_sed)
 
     if model is None:
-        raise TypeError('Model function is missing!')
+        raise TypeError("Model function is missing!")
 
     # Add parameter labels if not provided or too short
     if labels is None:
         # First is normalization
-        labels = ['norm'] + ['par{0}'.format(i) for i in range(1, len(p0))]
+        labels = ["norm"] + ["par{0}".format(i) for i in range(1, len(p0))]
     elif len(labels) < len(p0):
-        labels += ['par{0}'.format(i) for i in range(len(labels), len(p0))]
+        labels += ["par{0}".format(i) for i in range(len(labels), len(p0))]
 
     # Check that the model returns fluxes in same physical type as data
     modelout = model(p0, data)
-    if ((type(modelout) == tuple or type(modelout) == list) and
-            (type(modelout) != np.ndarray)):
+    if (type(modelout) == tuple or type(modelout) == list) and (
+        type(modelout) != np.ndarray
+    ):
         spec = modelout[0]
     else:
         spec = modelout
@@ -356,20 +395,24 @@ def get_sampler(data_table=None,
     try:
         # If both can be converted to differential flux, they can be compared
         # Otherwise, sed_conversion will raise a u.UnitsError
-        sed_conversion(data['energy'], spec.unit, False)
-        sed_conversion(data['energy'], data['flux'].unit, False)
+        sed_conversion(data["energy"], spec.unit, False)
+        sed_conversion(data["energy"], data["flux"].unit, False)
     except u.UnitsError:
         raise u.UnitsError(
-            'The physical type of the model and data units are not compatible,'
-            ' please modify your model or data so they match:\n'
-            ' Model units: {0} [{1}]\n Data units: {2} [{3}]\n'.format(
-                spec.unit, spec.unit.physical_type, data['flux'].unit, data[
-                    'flux'].unit.physical_type))
+            "The physical type of the model and data units are not compatible,"
+            " please modify your model or data so they match:\n"
+            " Model units: {0} [{1}]\n Data units: {2} [{3}]\n".format(
+                spec.unit,
+                spec.unit.physical_type,
+                data["flux"].unit,
+                data["flux"].unit.physical_type,
+            )
+        )
 
     if guess:
-        normNames = ['norm', 'Norm', 'ampl', 'Ampl', 'We', 'Wp']
-        normNameslog = ['log({0}'.format(name) for name in normNames]
-        normNameslog10 = ['log10({0}'.format(name) for name in normNames]
+        normNames = ["norm", "Norm", "ampl", "Ampl", "We", "Wp"]
+        normNameslog = ["log({0}".format(name) for name in normNames]
+        normNameslog10 = ["log10({0}".format(name) for name in normNames]
         normNames += normNameslog + normNameslog10
         idxs = []
         for l in normNames:
@@ -381,47 +424,58 @@ def get_sampler(data_table=None,
 
         if len(idxs) == 1:
 
-            nunit, sedf = sed_conversion(data['energy'], spec.unit, False)
-            currFlux = np.trapz(data['energy'] * (spec * sedf).to(nunit),
-                                data['energy'])
-            nunit, sedf = sed_conversion(data['energy'], data['flux'].unit,
-                                         False)
-            dataFlux = np.trapz(data['energy'] *
-                                (data['flux'] * sedf).to(nunit),
-                                data['energy'])
-            ratio = (dataFlux / currFlux)
-            if labels[idxs[0]].startswith('log('):
+            nunit, sedf = sed_conversion(data["energy"], spec.unit, False)
+            currFlux = np.trapz(
+                data["energy"] * (spec * sedf).to(nunit), data["energy"]
+            )
+            nunit, sedf = sed_conversion(
+                data["energy"], data["flux"].unit, False
+            )
+            dataFlux = np.trapz(
+                data["energy"] * (data["flux"] * sedf).to(nunit),
+                data["energy"],
+            )
+            ratio = dataFlux / currFlux
+            if labels[idxs[0]].startswith("log("):
                 p0[idxs[0]] += np.log(ratio)
-            elif labels[idxs[0]].startswith('log10('):
+            elif labels[idxs[0]].startswith("log10("):
                 p0[idxs[0]] += np.log10(ratio)
             else:
                 p0[idxs[0]] *= ratio
 
         elif len(idxs) == 0:
-            log.warning('No label starting with [{0}] found: not applying'
-                        ' normalization guess.'.format(','.join(normNames)))
+            log.warning(
+                "No label starting with [{0}] found: not applying"
+                " normalization guess.".format(",".join(normNames))
+            )
         elif len(idxs) > 1:
-            log.warning('More than one label starting with [{0}] found:'
-                        ' not applying normalization guess.'.format(','.join(
-                            normNames)))
+            log.warning(
+                "More than one label starting with [{0}] found:"
+                " not applying normalization guess.".format(
+                    ",".join(normNames)
+                )
+            )
 
     P0_IS_ML = False
     if interactive:
         try:
-            log.info(
-                'Launching interactive model fitter, close when finished')
+            log.info("Launching interactive model fitter, close when finished")
             from .model_fitter import InteractiveModelFitter
             import matplotlib.pyplot as plt
-            iprev = plt.rcParams['interactive']
-            plt.rcParams['interactive'] = False
+
+            iprev = plt.rcParams["interactive"]
+            plt.rcParams["interactive"] = False
             imf = InteractiveModelFitter(
-                model, p0, data, labels=labels, sed=True)
+                model, p0, data, labels=labels, sed=True
+            )
             p0 = imf.pars
             P0_IS_ML = imf.P0_IS_ML
-            plt.rcParams['interactive'] = iprev
+            plt.rcParams["interactive"] = iprev
         except ImportError as e:
-            log.warning('Interactive fitting is not available because'
-                        ' matplotlib is not installed: {0}'.format(e))
+            log.warning(
+                "Interactive fitting is not available because"
+                " matplotlib is not installed: {0}".format(e)
+            )
 
     # If we already did the prefit call in ModelWidget (and didn't modify the
     # parameters afterwards), avoid doing it here
@@ -429,7 +483,8 @@ def get_sampler(data_table=None,
         p0, P0_IS_ML = _prefit(p0, data, model, prior)
 
     sampler = emcee.EnsembleSampler(
-        nwalkers, len(p0), lnprob, args=[data, model, prior], threads=threads)
+        nwalkers, len(p0), lnprob, args=[data, model, prior], threads=threads
+    )
 
     # Add data and parameters properties to sampler
     sampler.data_table = data_table
@@ -439,11 +494,11 @@ def get_sampler(data_table=None,
     sampler.modelfn = model
     # Add run_info dict
     sampler.run_info = {
-        'n_walkers': nwalkers,
-        'n_burn': nburn,
+        "n_walkers": nwalkers,
+        "n_burn": nburn,
         # convert from np.float to regular float
-        'p0': [float(p) for p in p0],
-        'guess': guess,
+        "p0": [float(p) for p in p0],
+        "guess": guess,
     }
 
     # Initialize walkers in a ball of relative size 0.5% in all dimensions if
@@ -453,15 +508,17 @@ def get_sampler(data_table=None,
     p0 = emcee.utils.sample_ball(p0, p0var, nwalkers)
 
     if nburn > 0:
-        print('Burning in the {0} walkers with {1} steps...'.format(nwalkers,
-                                                                    nburn))
+        print(
+            "Burning in the {0} walkers with {1} steps...".format(
+                nwalkers, nburn
+            )
+        )
         sampler, pos = _run_mcmc(sampler, p0, nburn)
     else:
         pos = p0
 
-    sampler.run_info['p0_burn_median'] = [
-        float(p) for p in np.median(
-            pos, axis=0)
+    sampler.run_info["p0_burn_median"] = [
+        float(p) for p in np.median(pos, axis=0)
     ]
 
     return sampler, pos
@@ -497,9 +554,9 @@ def run_sampler(nrun=100, sampler=None, pos=None, **kwargs):
     if sampler is None or pos is None:
         sampler, pos = get_sampler(**kwargs)
 
-    sampler.run_info['n_run'] = nrun
+    sampler.run_info["n_run"] = nrun
 
-    print('\nWalker burn in finished, running {0} steps...'.format(nrun))
+    print("\nWalker burn in finished, running {0} steps...".format(nrun))
     sampler.reset()
     sampler, pos = _run_mcmc(sampler, pos, nrun)
 
