@@ -1,6 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+)
 
 import numpy as np
 import astropy.units as u
@@ -11,24 +15,28 @@ import ast
 from .extern.validator import validate_array, validate_scalar
 
 __all__ = [
-    "generate_energy_edges", "sed_conversion", "build_data_table", "estimate_B"
+    "generate_energy_edges",
+    "sed_conversion",
+    "build_data_table",
+    "estimate_B",
 ]
 
 # Input validation tools
 
 
-def validate_column(data_table, key, pt, domain='positive'):
+def validate_column(data_table, key, pt, domain="positive"):
     try:
         column = data_table[key]
         array = validate_array(
             key,
-            u.Quantity(
-                column, unit=column.unit),
+            u.Quantity(column, unit=column.unit),
             physical_type=pt,
-            domain=domain)
+            domain=domain,
+        )
     except KeyError:
         raise TypeError(
-            'Data table does not contain required column "{0}"'.format(key))
+            'Data table does not contain required column "{0}"'.format(key)
+        )
 
     return array
 
@@ -54,24 +62,25 @@ def validate_data_table(data_table, sed=None):
         for dt in data_table:
             if not isinstance(dt, Table) and not isinstance(dt, QTable):
                 raise TypeError(
-                    'An object passed as data_table is not an astropy Table!')
+                    "An object passed as data_table is not an astropy Table!"
+                )
     except TypeError:
         raise TypeError(
-            'Argument passed to validate_data_table is not a table and '
-            'not a list'
+            "Argument passed to validate_data_table is not a table and "
+            "not a list"
         )
 
     def dt_sed_conversion(dt, sed):
-        f_unit, sedf = sed_conversion(dt['energy'], dt['flux'].unit, sed)
+        f_unit, sedf = sed_conversion(dt["energy"], dt["flux"].unit, sed)
         # roundtrip to Table to change the units
         t = Table(dt)
-        for col in ['flux', 'flux_error_lo', 'flux_error_hi']:
+        for col in ["flux", "flux_error_lo", "flux_error_hi"]:
             t[col].unit = f_unit
         ndt = QTable(t)
 
-        ndt['flux'] = (dt['flux'] * sedf).to(f_unit)
-        ndt['flux_error_lo'] = (dt['flux_error_lo'] * sedf).to(f_unit)
-        ndt['flux_error_hi'] = (dt['flux_error_hi'] * sedf).to(f_unit)
+        ndt["flux"] = (dt["flux"] * sedf).to(f_unit)
+        ndt["flux_error_lo"] = (dt["flux_error_lo"] * sedf).to(f_unit)
+        ndt["flux_error_hi"] = (dt["flux_error_hi"] * sedf).to(f_unit)
 
         return ndt
 
@@ -82,19 +91,21 @@ def validate_data_table(data_table, sed=None):
 
     # concatenate input data tables
     data_new = data_list[0].copy()
-    f_pt = data_new['flux'].unit.physical_type
+    f_pt = data_new["flux"].unit.physical_type
     if sed is None:
-        sed = f_pt in ['flux', 'power']
+        sed = f_pt in ["flux", "power"]
 
     data_new = dt_sed_conversion(data_new, sed)
 
     for dt in data_list[1:]:
-        nf_pt = dt['flux'].unit.physical_type
-        if (('flux' in nf_pt and 'power' in f_pt) or
-                ('power' in nf_pt and 'flux' in f_pt)):
+        nf_pt = dt["flux"].unit.physical_type
+        if ("flux" in nf_pt and "power" in f_pt) or (
+            "power" in nf_pt and "flux" in f_pt
+        ):
             raise TypeError(
-                'The physical types of the data tables could not be '
-                'matched: Some are in flux and others in luminosity units')
+                "The physical types of the data tables could not be "
+                "matched: Some are in flux and others in luminosity units"
+            )
 
         dt = dt_sed_conversion(dt, sed)
 
@@ -108,100 +119,114 @@ def _validate_single_data_table(data_table, group=0):
 
     data = QTable()
 
-    flux_types = ['flux', 'differential flux', 'power', 'differential power']
+    flux_types = ["flux", "differential flux", "power", "differential power"]
 
     # Energy and flux arrays
-    data['energy'] = validate_column(data_table, 'energy', 'energy')
-    data['flux'] = validate_column(data_table, 'flux', flux_types)
+    data["energy"] = validate_column(data_table, "energy", "energy")
+    data["flux"] = validate_column(data_table, "flux", flux_types)
 
     # Flux uncertainties
-    if 'flux_error' in data_table.keys():
-        dflux = validate_column(data_table, 'flux_error', flux_types)
-        data['flux_error_lo'] = dflux
-        data['flux_error_hi'] = dflux
-    elif 'flux_error_lo' in data_table.keys(
-    ) and 'flux_error_hi' in data_table.keys():
-        data['flux_error_lo'] = validate_column(data_table, 'flux_error_lo',
-                                                flux_types)
-        data['flux_error_hi'] = validate_column(data_table, 'flux_error_hi',
-                                                flux_types)
+    if "flux_error" in data_table.keys():
+        dflux = validate_column(data_table, "flux_error", flux_types)
+        data["flux_error_lo"] = dflux
+        data["flux_error_hi"] = dflux
+    elif (
+        "flux_error_lo" in data_table.keys()
+        and "flux_error_hi" in data_table.keys()
+    ):
+        data["flux_error_lo"] = validate_column(
+            data_table, "flux_error_lo", flux_types
+        )
+        data["flux_error_hi"] = validate_column(
+            data_table, "flux_error_hi", flux_types
+        )
     else:
-        raise TypeError('Data table does not contain required column'
-                        ' "flux_error" or columns "flux_error_lo"'
-                        ' and "flux_error_hi"')
+        raise TypeError(
+            "Data table does not contain required column"
+            ' "flux_error" or columns "flux_error_lo"'
+            ' and "flux_error_hi"'
+        )
 
-    if 'group' in data_table.colnames:
+    if "group" in data_table.colnames:
         # avoid overwriting groups
-        data['group'] = data_table['group']
+        data["group"] = data_table["group"]
     else:
-        data['group'] = [group] * len(data['energy'])
+        data["group"] = [group] * len(data["energy"])
 
     # Energy bin edges
-    if 'energy_width' in data_table.keys():
-        energy_width = validate_column(data_table, 'energy_width', 'energy')
-        data['energy_error_lo'] = energy_width / 2.
-        data['energy_error_hi'] = energy_width / 2.
-    elif 'energy_error' in data_table.keys():
-        energy_error = validate_column(data_table, 'energy_error', 'energy')
-        data['energy_error_lo'] = energy_error
-        data['energy_error_hi'] = energy_error
-    elif ('energy_error_lo' in data_table.keys() and
-          'energy_error_hi' in data_table.keys()):
-        energy_error_lo = validate_column(data_table, 'energy_error_lo',
-                                          'energy')
-        data['energy_error_lo'] = energy_error_lo
-        energy_error_hi = validate_column(data_table, 'energy_error_hi',
-                                          'energy')
-        data['energy_error_hi'] = energy_error_hi
-    elif 'energy_lo' in data_table.keys() and 'energy_hi' in data_table.keys():
-        energy_lo = validate_column(data_table, 'energy_lo', 'energy')
-        data['energy_error_lo'] = (data['energy'] - energy_lo)
-        energy_hi = validate_column(data_table, 'energy_hi', 'energy')
-        data['energy_error_hi'] = (energy_hi - data['energy'])
+    if "energy_width" in data_table.keys():
+        energy_width = validate_column(data_table, "energy_width", "energy")
+        data["energy_error_lo"] = energy_width / 2.0
+        data["energy_error_hi"] = energy_width / 2.0
+    elif "energy_error" in data_table.keys():
+        energy_error = validate_column(data_table, "energy_error", "energy")
+        data["energy_error_lo"] = energy_error
+        data["energy_error_hi"] = energy_error
+    elif (
+        "energy_error_lo" in data_table.keys()
+        and "energy_error_hi" in data_table.keys()
+    ):
+        energy_error_lo = validate_column(
+            data_table, "energy_error_lo", "energy"
+        )
+        data["energy_error_lo"] = energy_error_lo
+        energy_error_hi = validate_column(
+            data_table, "energy_error_hi", "energy"
+        )
+        data["energy_error_hi"] = energy_error_hi
+    elif "energy_lo" in data_table.keys() and "energy_hi" in data_table.keys():
+        energy_lo = validate_column(data_table, "energy_lo", "energy")
+        data["energy_error_lo"] = data["energy"] - energy_lo
+        energy_hi = validate_column(data_table, "energy_hi", "energy")
+        data["energy_error_hi"] = energy_hi - data["energy"]
     else:
-        data['energy_error_lo'], data[
-            'energy_error_hi'] = generate_energy_edges(
-                data['energy'], groups=data['group'])
+        data["energy_error_lo"], data[
+            "energy_error_hi"
+        ] = generate_energy_edges(data["energy"], groups=data["group"])
 
     # Upper limit flags
-    if 'ul' in data_table.keys():
+    if "ul" in data_table.keys():
         # Check if it is a integer or boolean flag
-        ul_col = data_table['ul']
+        ul_col = data_table["ul"]
         if ul_col.dtype.type is np.int_ or ul_col.dtype.type is np.bool_:
-            data['ul'] = np.array(ul_col, dtype=np.bool)
+            data["ul"] = np.array(ul_col, dtype=np.bool)
         elif ul_col.dtype.type is np.str_:
             strbool = True
             for ul in ul_col:
-                if ul != 'True' and ul != 'False':
+                if ul != "True" and ul != "False":
                     strbool = False
             if strbool:
-                data['ul'] = np.array(
-                    [ast.literal_eval(ul) for ul in ul_col], dtype=np.bool)
+                data["ul"] = np.array(
+                    [ast.literal_eval(ul) for ul in ul_col], dtype=np.bool
+                )
             else:
-                raise TypeError('UL column is in wrong format')
+                raise TypeError("UL column is in wrong format")
         else:
-            raise TypeError('UL column is in wrong format')
+            raise TypeError("UL column is in wrong format")
     else:
-        data['ul'] = np.array([False] * len(data['energy']))
+        data["ul"] = np.array([False] * len(data["energy"]))
 
-    if 'flux_ul' in data_table.keys():
-        data['flux'][data['ul']] = u.Quantity(
-            data_table['flux_ul'])[data['ul']]
+    if "flux_ul" in data_table.keys():
+        data["flux"][data["ul"]] = u.Quantity(data_table["flux_ul"])[
+            data["ul"]
+        ]
 
     HAS_CL = False
-    if 'keywords' in data_table.meta.keys():
-        if 'cl' in data_table.meta['keywords'].keys():
+    if "keywords" in data_table.meta.keys():
+        if "cl" in data_table.meta["keywords"].keys():
             HAS_CL = True
-            CL = validate_scalar('cl',
-                                 data_table.meta['keywords']['cl']['value'])
-            data['cl'] = [CL] * len(data['energy'])
+            CL = validate_scalar(
+                "cl", data_table.meta["keywords"]["cl"]["value"]
+            )
+            data["cl"] = [CL] * len(data["energy"])
 
     if not HAS_CL:
-        data['cl'] = [0.9] * len(data['energy'])
-        if np.sum(data['ul']) > 0:
+        data["cl"] = [0.9] * len(data["energy"])
+        if np.sum(data["ul"]) > 0:
             log.warning(
                 '"cl" keyword not provided in input data table, upper limits'
-                ' will be assumed to be at 90% confidence level')
+                " will be assumed to be at 90% confidence level"
+            )
 
     return data
 
@@ -220,44 +245,49 @@ def sed_conversion(energy, model_unit, sed):
 
     if sed:
         # SED
-        f_unit = u.Unit('erg/s')
-        if model_pt == 'power' or model_pt == 'flux' or model_pt == 'energy':
+        f_unit = u.Unit("erg/s")
+        if model_pt == "power" or model_pt == "flux" or model_pt == "energy":
             sedf = ones
-        elif 'differential' in model_pt:
-            sedf = (energy**2)
+        elif "differential" in model_pt:
+            sedf = energy ** 2
         else:
             raise u.UnitsError(
-                'Model physical type ({0}) is not supported'.format(model_pt),
-                'Supported physical types are: power, flux, differential'
-                ' power, differential flux')
+                "Model physical type ({0}) is not supported".format(model_pt),
+                "Supported physical types are: power, flux, differential"
+                " power, differential flux",
+            )
 
-        if 'flux' in model_pt:
-            f_unit /= u.cm**2
-        elif 'energy' in model_pt:
+        if "flux" in model_pt:
+            f_unit /= u.cm ** 2
+        elif "energy" in model_pt:
             # particle energy distributions
             f_unit = u.erg
     else:
         # Differential spectrum
-        f_unit = u.Unit('1/(s TeV)')
-        if 'differential' in model_pt:
+        f_unit = u.Unit("1/(s TeV)")
+        if "differential" in model_pt:
             sedf = ones
-        elif model_pt == 'power' or model_pt == 'flux' or model_pt == 'energy':
+        elif model_pt == "power" or model_pt == "flux" or model_pt == "energy":
             # From SED to differential
-            sedf = 1 / (energy**2)
+            sedf = 1 / (energy ** 2)
         else:
             raise u.UnitsError(
-                'Model physical type ({0}) is not supported'.format(model_pt),
-                'Supported physical types are: power, flux, differential'
-                ' power, differential flux')
+                "Model physical type ({0}) is not supported".format(model_pt),
+                "Supported physical types are: power, flux, differential"
+                " power, differential flux",
+            )
 
-        if 'flux' in model_pt:
-            f_unit /= u.cm**2
-        elif 'energy' in model_pt:
+        if "flux" in model_pt:
+            f_unit /= u.cm ** 2
+        elif "energy" in model_pt:
             # particle energy distributions
-            f_unit = u.Unit('1/TeV')
+            f_unit = u.Unit("1/TeV")
 
-    log.debug('Converted from {0} ({1}) into {2} ({3}) for sed={4}'.format(
-        model_unit, model_pt, f_unit, f_unit.physical_type, sed))
+    log.debug(
+        "Converted from {0} ({1}) into {2} ({3}) for sed={4}".format(
+            model_unit, model_pt, f_unit, f_unit.physical_type, sed
+        )
+    )
 
     return f_unit, sedf
 
@@ -287,12 +317,12 @@ def trapz_loglog(y, x, axis=-1, intervals=False):
         y_unit = y.unit
         y = y.value
     except AttributeError:
-        y_unit = 1.
+        y_unit = 1.0
     try:
         x_unit = x.unit
         x = x.value
     except AttributeError:
-        x_unit = 1.
+        x_unit = 1.0
 
     y = np.asanyarray(y)
     x = np.asanyarray(x)
@@ -302,6 +332,9 @@ def trapz_loglog(y, x, axis=-1, intervals=False):
     slice1[axis] = slice(None, -1)
     slice2[axis] = slice(1, None)
 
+    slice1 = tuple(slice1)
+    slice2 = tuple(slice2)
+
     if x.ndim == 1:
         shape = [1] * y.ndim
         shape[axis] = x.shape[0]
@@ -315,12 +348,17 @@ def trapz_loglog(y, x, axis=-1, intervals=False):
         # if local powerlaw index is -1, use \int 1/x = log(x); otherwise use
         # normal powerlaw integration
         trapzs = np.where(
-            np.abs(b + 1.) > 1e-10, (y[slice1] * (
-                x[slice2] * (x[slice2] / x[slice1])**b - x[slice1])) / (b + 1),
-            x[slice1] * y[slice1] * np.log(x[slice2] / x[slice1]))
+            np.abs(b + 1.0) > 1e-10,
+            (
+                y[slice1]
+                * (x[slice2] * (x[slice2] / x[slice1]) ** b - x[slice1])
+            )
+            / (b + 1),
+            x[slice1] * y[slice1] * np.log(x[slice2] / x[slice1]),
+        )
 
-    tozero = (y[slice1] == 0.) + (y[slice2] == 0.) + (x[slice1] == x[slice2])
-    trapzs[tozero] = 0.
+    tozero = (y[slice1] == 0.0) + (y[slice2] == 0.0) + (x[slice1] == x[slice2])
+    trapzs[tozero] = 0.0
 
     if intervals:
         return trapzs * x_unit * y_unit
@@ -370,16 +408,18 @@ def generate_energy_edges(ene, groups=None):
         return eloehi
 
 
-def build_data_table(energy,
-                     flux,
-                     flux_error=None,
-                     flux_error_lo=None,
-                     flux_error_hi=None,
-                     energy_width=None,
-                     energy_lo=None,
-                     energy_hi=None,
-                     ul=None,
-                     cl=None):
+def build_data_table(
+    energy,
+    flux,
+    flux_error=None,
+    flux_error_lo=None,
+    flux_error_hi=None,
+    energy_width=None,
+    energy_lo=None,
+    energy_hi=None,
+    ul=None,
+    cl=None,
+):
     """
     Read data into data dict.
 
@@ -419,32 +459,32 @@ def build_data_table(energy,
     table = QTable()
 
     if cl is not None:
-        cl = validate_scalar('cl', cl)
-        table.meta['keywords'] = {'cl': {'value': cl}}
+        cl = validate_scalar("cl", cl)
+        table.meta["keywords"] = {"cl": {"value": cl}}
 
-    table['energy'] = energy
+    table["energy"] = energy
 
     if energy_width is not None:
-        table['energy_width'] = energy_width
+        table["energy_width"] = energy_width
     elif energy_lo is not None and energy_hi is not None:
-        table['energy_lo'] = energy_lo
-        table['energy_hi'] = energy_hi
+        table["energy_lo"] = energy_lo
+        table["energy_hi"] = energy_hi
 
-    table['flux'] = flux
+    table["flux"] = flux
 
     if flux_error is not None:
-        table['flux_error'] = flux_error
+        table["flux_error"] = flux_error
     elif flux_error_lo is not None and flux_error_hi is not None:
-        table['flux_error_lo'] = flux_error_lo
-        table['flux_error_hi'] = flux_error_hi
+        table["flux_error_lo"] = flux_error_lo
+        table["flux_error_hi"] = flux_error_hi
     else:
-        raise TypeError('Flux error not provided!')
+        raise TypeError("Flux error not provided!")
 
     if ul is not None:
         ul = np.array(ul, dtype=np.int)
-        table['ul'] = ul
+        table["ul"] = ul
 
-    table.meta['comments'] = ['Table generated with naima.build_data_table']
+    table.meta["comments"] = ["Table generated with naima.build_data_table"]
 
     # test table units, format, etc
     validate_data_table(table)
@@ -452,9 +492,9 @@ def build_data_table(energy,
     return table
 
 
-def estimate_B(xray_table,
-               vhe_table,
-               photon_energy_density=0.261 * u.eV / u.cm**3):
+def estimate_B(
+    xray_table, vhe_table, photon_energy_density=0.261 * u.eV / u.cm ** 3
+):
     """ Estimate magnetic field from synchrotron to Inverse Compton luminosity
     ratio
 
@@ -503,12 +543,13 @@ def estimate_B(xray_table,
     xray = validate_data_table(xray_table, sed=False)
     vhe = validate_data_table(vhe_table, sed=False)
 
-    xray_lum = trapz_loglog(xray['flux'] * xray['energy'], xray['energy'])
-    vhe_lum = trapz_loglog(vhe['flux'] * vhe['energy'], vhe['energy'])
+    xray_lum = trapz_loglog(xray["flux"] * xray["energy"], xray["energy"])
+    vhe_lum = trapz_loglog(vhe["flux"] * vhe["energy"], vhe["energy"])
 
-    uph = (photon_energy_density.to('erg/cm3')).value
+    uph = (photon_energy_density.to("erg/cm3")).value
 
-    B0 = (np.sqrt((xray_lum / vhe_lum).decompose().value * 8 * np.pi * uph) *
-          u.G).to('uG')
+    B0 = (
+        np.sqrt((xray_lum / vhe_lum).decompose().value * 8 * np.pi * uph) * u.G
+    ).to("uG")
 
     return B0
